ryvencore.InfoMsgs module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.InfoMsgs module

class InfoMsgs

  Bases: `object`

  A few handy static methods for writing different kinds of messages to the output console only if info msgs are enabled.

  enabled = False
  enabled_errors = False
  traceback_enabled = False
  static enable(traceback=False)
  static enable_errors(traceback=True)
  static disable()
  static write(*args)
  static write_err(*args)

class MSG_COLORS

  Bases: `object`

  HEADER = '\x1b[95m'
  OKBLUE = '\x1b[94m'
  OKCYAN = '\x1b[96m'
  OKGREEN = '\x1b[92m'
  WARNING = '\x1b[93m'
  FAIL = '\x1b[91m'
  ENDC = '\x1b[0m'
  BOLD = '\x1b[1m'
  UNDERLINE = '\x1b[4m'